@@ -1,14 +1,5 @@
 bound <- function(target,n.cohort,cohortsize,cutoff,K,cutoff_e=5/24){
 
-  f <- function(n,x){
-    ((n+2)*x/(n*x+1))^(n*x)
-  }
-
-  cut5 <- function(t,target, n, K){
-    f(t,target)*f(t,1-target)*(1+(n/10)/t/K)^(K*t/(n/10))
-  }
-
-
   lower <- upper <- 0
   lower.ex <- upper.ex <- 0
   for(i in 1:n.cohort){
@@ -17,12 +8,8 @@ bound <- function(target,n.cohort,cohortsize,cutoff,K,cutoff_e=5/24){
     y <- lapply(x,prbf01,n=(i*cohortsize),target=target)
     a <- 0
 
-    if (cutoff){cutoff2 <- cut5(t=t,target=target, n=n.cohort*cohortsize, K=K)}
-    # either cutoff is a numeric (default = 2.5), or provide b1 b2 b3 to calculate.
-    if (is.numeric(cutoff)==TRUE){cutoff2 <- cutoff}
-
     for(j in 1:length(x)){
-      if(y[[j]]<cutoff2){ #e,exp(1)*(1/t*log(1+t))^(1/(2*t)),exp(1)*(1/t*log(1+t))^(1/(t))
+      if(y[[j]]<cutoff){ #e,exp(1)*(1/t*log(1+t))^(1/(2*t)),exp(1)*(1/t*log(1+t))^(1/(t))
         if(x[j]/(i*cohortsize)<target){
           a[j] <- 1
         }else{
